@@ -1,4 +1,4 @@
-/* Copyright (C) 2005-2010, Thorvald Natvig <thorvald@natvig.com>
+/* Copyright (C) 2005-2011, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
 
@@ -28,7 +28,10 @@
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
+#include "mumble_pch.hpp"
+
 #include "ASIOInput.h"
+
 #include "MainWindow.h"
 #include "Global.h"
 
@@ -68,6 +71,7 @@ class ASIOInit : public DeferInit {
 		ASIOAudioInputRegistrar *airASIO;
 		ConfigRegistrar *crASIO;
 	public:
+		ASIOInit() : airASIO(NULL), crASIO(NULL) {}
 		void initialize();
 		void destroy();
 };
@@ -75,10 +79,7 @@ class ASIOInit : public DeferInit {
 void ASIOInit::initialize() {
 	HKEY hkDevs;
 	HKEY hk;
-	WCHAR keyname[255];
-	DWORD keynamelen = 255;
 	FILETIME ft;
-	HRESULT hr;
 
 	airASIO = NULL;
 	crASIO = NULL;
@@ -94,6 +95,8 @@ void ASIOInit::initialize() {
 #endif
 	if (RegOpenKeyEx(HKEY_LOCAL_MACHINE, L"Software\\ASIO", 0, KEY_READ, &hkDevs) == ERROR_SUCCESS) {
 		DWORD idx = 0;
+		DWORD keynamelen = 255;
+		WCHAR keyname[255];
 		while (RegEnumKeyEx(hkDevs, idx++, keyname, &keynamelen, NULL, NULL, NULL, &ft)  == ERROR_SUCCESS) {
 			QString name=QString::fromUtf16(reinterpret_cast<ushort *>(keyname),keynamelen);
 			if (RegOpenKeyEx(hkDevs, keyname, 0, KEY_READ, &hk) == ERROR_SUCCESS) {
@@ -105,7 +108,7 @@ void ASIOInit::initialize() {
 					if (datasize > 76)
 						datasize = 76;
 					QString qsCls = QString::fromUtf16(reinterpret_cast<ushort *>(wclsid), datasize / 2).toLower().trimmed();
-					if (! blacklist.contains(qsCls.toLower()) && ! FAILED(hr =CLSIDFromString(wclsid, &clsid))) {
+					if (! blacklist.contains(qsCls.toLower()) && ! FAILED(CLSIDFromString(wclsid, &clsid))) {
 						bFound = true;
 					}
 				}
@@ -403,8 +406,6 @@ ASIOInput::ASIOInput() {
 	abiInfo = NULL;
 	aciInfo = NULL;
 
-	int i, idx;
-
 	// Sanity check things first.
 
 	iNumMic=g.s.qlASIOmic.count();
@@ -465,7 +466,8 @@ ASIOInput::ASIOInput() {
 
 			abiInfo = new ASIOBufferInfo[iNumMic + iNumSpeaker];
 			aciInfo = new ASIOChannelInfo[iNumMic + iNumSpeaker];
-			idx = 0;
+
+			int i, idx = 0;
 			for (i=0;i<iNumMic;i++) {
 				abiInfo[idx].isInput = true;
 				abiInfo[idx].channelNum = g.s.qlASIOmic[i].toInt();
